@@ -17,7 +17,7 @@ DO_MYSQL_PASS=
 DO_MYSQL_DBNAME=do_test
 DO_MYSQL_DATABASE=/${DO_MYSQL_DBNAME}
 
-mysql_install_db --no-defaults --datadir=${MYTEMP_DIR} --insecure --basedir=/usr --user=${DO_MYSQL_USER}
+/usr/sbin/mysqld --no-defaults --initialize-insecure --user=${DO_MYSQL_USER} --datadir=${MYTEMP_DIR}
 /usr/sbin/mysqld --no-defaults --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} --datadir=${MYTEMP_DIR} --skip-networking &
 echo -n pinging mysqld.
 attempts=0
@@ -30,7 +30,7 @@ while ! /usr/bin/mysqladmin --socket=${MYSQL_UNIX_PORT} ping ; do
 	fi
 done
 mysql --socket=${MYSQL_UNIX_PORT} --execute "CREATE DATABASE ${DO_MYSQL_DBNAME};"
-mysql --socket=${MYSQL_UNIX_PORT} --execute "GRANT ALL PRIVILEGES ON ${DO_MYSQL_DBNAME}.* TO '${DO_MYSQL_USER}'@'localhost' IDENTIFIED BY '${DO_MYSQL_PASS}';"
+mysql --socket=${MYSQL_UNIX_PORT} --execute "GRANT ALL PRIVILEGES ON ${DO_MYSQL_DBNAME}.* TO '${DO_MYSQL_USER}'@'localhost';"
 
 # Keep running so we can terminate mysqld.
 set +e
